Fast5_research
--------------

Fast5 reading and writing functionality provided by ONT Research.

[![Build Status](https://travis-ci.org/nanoporetech/fast5_research.svg?branch=master)](https://travis-ci.org/nanoporetech/fast5_research)
